Adjust clang format to the new versions, revert broken macro layout (#714)

This commit is contained in:
Danylo Lytovchenko
2025-08-22 17:23:22 +02:00
committed by GitHub
parent ed877433f3
commit 2ff2316227
189 changed files with 1906 additions and 2418 deletions
@@ -30,9 +30,9 @@ __device__ static void* dev_ptr[num_threads][GRIDSIZE];
* This kernel allocates and deallocates in every thread
* of every block.
*/
template <typename T>
static __global__ void kerTestDynamicAllocInAllThread(T* outputBuf, int test_type, T value,
size_t perThreadSize) {
template <typename T> static __global__ void kerTestDynamicAllocInAllThread(T* outputBuf,
int test_type, T value,
size_t perThreadSize) {
int myId = threadIdx.x + blockDim.x * blockIdx.x;
// Allocate
size_t size = 0;